# namespace package boilerplate
try:
    import pkg_resources
    pkg_resources.declare_namespace(__name__)
except ImportError:
    from pkgutil import extend_path
    __path__ = extend_path(__path__, __name__)



# -*- coding: utf-8 -*-

import unittest, doctest
import grokui.base
from zope.fanstatic.testing import ZopeFanstaticBrowserLayer

def test_suite():
    suite = unittest.TestSuite()
    readme = doctest.DocFileSuite(
        '../README.txt',
        optionflags=(doctest.ELLIPSIS|doctest.NORMALIZE_WHITESPACE|
                     doctest.REPORT_NDIFF))
    readme.layer = ZopeFanstaticBrowserLayer(grokui.base)
    suite.addTest(readme)
    return suite


if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')



# -*- coding: utf-8 -*-

from zope.interface import Interface, Attribute


class IMainMenu(Interface):
    """A menu that allows the access to the different UI panels.
    """


class IUIPanel(Interface):
    """A panel of administration.
    """


class IGrokUIRealm(Interface):
    """Represents an abstract object that acts as the UI namespace.
    It provides an access to the very root folder and to the request.
    """
    root = Attribute("The root folder object.")
    request = Attribute("The HTTP request object.")



from zope.traversing.browser.absoluteurl import absoluteURL
import grok
from grokui.base import IGrokUIRealm, GrokUILayer, IUIPanel, MainMenu
from grokui.base import resource
import megrok.menu

grok.layer(GrokUILayer)


class GrokUILayout(grok.Layout):
    """The general layout for the administration
    """
    grok.context(IGrokUIRealm)
    title = u"Grok User Interface"

    def update(self):
        resource.grok_css.need()
        resource.favicon.need()
        self.baseurl = absoluteURL(self.context, self.request) + '/'


class GrokUIView(grok.Page):
    """A grok ui view.
    """
    grok.baseclass()
    grok.context(IGrokUIRealm)
    grok.implements(IUIPanel)
    megrok.menu.menuitem(MainMenu)



# -*- coding: utf-8 -*-
import grok
from grokcore.message import UniqueMessageSource


class AdminMessageSource(UniqueMessageSource):
    """Source for the administration messages
    """
    grok.name('admin')

    def send(self, message, type="admin"):
        return UniqueMessageSource.send(self, message, type=type)

    def list(self, type="admin"):
        return UniqueMessageSource.list(self, type=type)
